@@ -16,9 +16,9 @@ class  RegressionData
 	protected:
 		const RNumericMatrix locations_;		//!< Design matrix pointer and dimensions.
 		VectorXr 	   observations_; 		//!< Observations data
-		bool 		   locations_by_nodes_; 	//!< If location is on the mesh nodes or not.
-		UInt 		   nRegions_; 			//!< For areal data.
-		bool 		   arealDataAvg_; 		//!< Is areal data averaged ?
+		bool 		   locations_by_nodes_{}; 	//!< If location is on the mesh nodes or not.
+		UInt 		   nRegions_ = 0; 		//!< For areal data.
+		bool 		   arealDataAvg_{}; 		//!< Is areal data averaged ?
 		VectorXr	   WeightsMatrix_; 		//!< Weighted regression.
 		bool           isGAM = false;
 
@@ -32,10 +32,10 @@ class  RegressionData
 		// Barycenter information
 		VectorXi element_ids_; 				//!< Elements id information
 		MatrixXr barycenters_; 				//!< Barycenter information
-		bool locations_by_barycenter_;
+		bool locations_by_barycenter_{};
 
 		// Other parameters
-		UInt order_;
+		UInt order_ = 0;
 
 		// Boundary + Initial
 		std::vector<Real> bc_values_;
@@ -44,21 +44,21 @@ class  RegressionData
 
 		// Design matrix
 		MatrixXr covariates_;
-		UInt n_;
-		UInt p_;
+		UInt n_ = 0;
+		UInt p_ = 0;
 
 		// Areal data
 		MatrixXi incidenceMatrix_;
 
-		bool flag_mass_;				//!< Mass penalization, only for separable version (flag_parabolic_==FALSE)
-		bool flag_parabolic_;
-		bool flag_iterative_;     //!<True if iterative-method for space time smoothing is selected
-		bool flag_SpaceTime_; // TRUE if space time smoothing
-		UInt search_; // search algorith type
+		bool flag_mass_{};				//!< Mass penalization, only for separable version (flag_parabolic_==FALSE)
+		bool flag_parabolic_{};
+		bool flag_iterative_{};     			//!<True if iterative-method for space time smoothing is selected
+		bool flag_SpaceTime_{}; 			// TRUE if space time smoothing
+		UInt search_ = 0; 				// search algorith type
 
-        // Iterative method
-        UInt max_num_iterations_; //!< Max number of iterations allowed
-        Real threshold_; //!< Limit in difference among J_k and J_k+1 for which we stop iterative method.
+        	// Iterative method
+        	UInt max_num_iterations_ = 0; 			//!< Max number of iterations allowed
+        	Real threshold_ = 0.; 				//!< Limit in difference among J_k and J_k+1 for which we stop iterative method.
 
 		// -- SETTERS --
 		void setObservations(SEXP Robservations);
